# -*- coding: utf-8 -*-
"""
Created on Sun Jan 15 23:07:01 2023

@author: Administrator
"""
import subprocess


def powershell(file, o):
    try:
        # args参数里的ip是对应调用powershell里的动态参数args[0],类似python中的sys.argv[1]
        args = [r"powershell.exe", "-ExecutionPolicy",
                "Unrestricted", *file, *o]
        p = subprocess.Popen(args, stdout=subprocess.PIPE)
        dt = p.stdout.read()
        return dt
    except Exception as e:
        print(e)
    return False


def cmd(command):
    subp = subprocess.Popen(command, shell=True, stdout=subprocess.PIPE,
                            stderr=subprocess.PIPE, encoding="utf-8")
    subp.wait()
    if subp.poll() == 0:
        print(subp.communicate()[1])
    else:
        print("失败")


# 如果报错，说禁止执行脚本，是因为没有权限，所以，把上面的一行代码换成
#args=[r"C:\WINDOWS\system32\WindowsPowerShell\v1.0\powershell.exe","-ExecutionPolicy","Unrestricted", r"D:\jzhou\test_ping.ps1",ip]



import shutil,os,platform
def cpfiledata(a, b):
    try:
        file1 = open(a)
        file2 = open(b, "w")
        shutil.copyfileobj(file1, file2)
    except IOError as e:
        print("could not open file or no such file:", e)
        print("无法打开文件或无此文件：", e)


def cpflieper(src, dst):
    try:
        if os.path.isdir(dst):
            dst = os.path.join(dst, os.path.basename(src))
            shutil.copyfile(src, dst)
            shutil.copymode(src, dst)
    except IOError as e:
        print("could not open file or no such files:", e)
        print("无法打开文件或无该文件：", e)


def cpfiletree(a, b):
    try:
        shutil.copytree(a, b)
    except IOError as e:
        print("could not open file or no such files:", e)
        print("无法打开文件树或无该文件树：", e)


# noinspection PyUnboundLocalVariable
def rmtree(fdir):
    try:
        shutil.rmtree(fdir)
    except IOError as e:
        print("could not open file or no such files:", e)
        print("无法打开文件或无该文件：", e)


def mvfile(src, dst):
    try:
        shutil.move(src, dst)
    except IOError as e:
        print("could not open file or no such files:", e)
        print("无法打开文件或无该文件：", e)


def rmfile(src):
    try:
        os.remove(src)
    except IOError as e:
        print("could not open file or no such files:", e)
        print("无法打开文件或无该文件：", e)


def renames(old, new):
    try:
        os.renames(old, new)
    except IOError as e:
        print("could not open file or no such files:", e)
        print("无法打开文件或无该文件：", e)


def path(file):
    # B  ct=25920000
    print("文件名：" + os.path.basename(file))
    # B  print( '最近访问时间：'+str(int(float(os.path.getatime(file))/ct))+'天前' )
    # B  print( '创建时间：'+str(float(os.path.getctime(file))/ct)+'天前' )
    # B  print( '最近修改时间：'+str(int(float(os.path.getmtime(file))/ct))+'天前' )

    if int(os.path.getsize(file)) >= 1024 * 1024 * 1024 * 1024 * 1024:
        print(
            "文件大小："
            + str(int(os.path.getsize(file)) / 1125899906842624)
            + "Pib"
        )
    elif int(os.path.getsize(file)) >= 1024 * 1024 * 1024 * 1024:
        print(
            "文件大小：" + str(int(os.path.getsize(file)) / 1099511627776) + "Tib"
        )
    elif int(os.path.getsize(file)) >= 1024 * 1024 * 1024:
        print("文件大小：" + str(int(os.path.getsize(file)) / 1073741824) + "Gib")
    elif int(os.path.getsize(file)) >= 1024 * 1024:
        print("文件大小：" + str(int(os.path.getsize(file)) / 1048576) + "Mib")
    elif int(os.path.getsize(file)) >= 1024:
        print("文件大小：" + str(int(os.path.getsize(file)) / 1024) + "Kib")
    else:
        print("文件大小：" + str(int(os.path.getsize(file))) + "B")
    print("文件路径：", os.path.abspath(file))  # 输出绝对路径
    print(os.path.normpath(file))  # 规范path字符串形式


def cpfile(a, b):
    try:
        shutil.copyfile(a, b)
    except IOError as e:
        print("could not open file or no such files:", e)
        print("无法打开文件或无该文件：", e)


def listfile(tdir):
    plat = platform.system().lower()
    if plat == "windows":
        if tdir == "":
            os.system("dir")
        else:
            os.system("cd %s" % tdir)
            os.system("dir")
    else:
        if tdir == "":
            os.system("ls")
        else:
            os.system("cd %s" % tdir)
            os.system("ls")


# -*- coding: utf-8 -*-
"""
Created on Fri Jan 13 19:03:14 2023

@author: Administrator
"""
import pip
import subprocess
from rich.progress import track as tqdm


def install(pkg):
    for _ in tqdm(subprocess.call('pip install ' + pkg + ' --use-pep517', shell=True), description='install'):
        pass


def upgrade(pkg):
    pip(['install', '-U', pkg])


def uninstall(pkg):
    pip.main(['uninstall', pkg])


def download(pkg):
    pip.main(['download', pkg])


def reinstall(pkg):
    uninstall(pkg)
    install(pkg)

# noinspection PyTypeChecker


class config:
    def set(*value):
        pip.main(['config', 'set', value])

    def edit(edor):
        if edor == '':
            pip.main(['config', 'edit'])
        else:
            pip.main(['config', '--editor=' + edor, 'edit'])

    def debug():
        pip.main(['config', 'debug'])

    def unset(cfg):
        pip.main(['config', 'unset', cfg])



# -*- coding: utf-8 -*-
"""
Created on Sun Jan  8 16:52:17 2023

@author: Administrator
"""
__all__ = ['archive.py', 'file.py', 'sudo.py', 'pip.py','ntp.py','piptools.py']
import platform
import os
import archive
import piptools,subprocess
import winshell
# logog=''''''
# logoe=''''''


def __runfst__():
    __fc = 'Python Version:'+' '+platform.python_version()
    __et = 'PKG Version:'+'0.3.2'
    print(__et)
    print(__fc)


# %%Gets the operating system type
if __name__ == '__main__':
    # %%Logo

    logo = '''
    ╔════╦═══╦═══╦╗  ╔╗╔═╦══╦════╗
    ║╔╗╔╗║╔═╗║╔═╗║║  ║║║╔╩╣╠╣╔╗╔╗║
    ╚╝║║╚╣║ ║║║ ║║║  ║╚╝║ ║║╚╝║║╚╝
      ║║ ║║ ║║║ ║║║ ╔╣╔╗║ ║║  ║║
      ║║ ║╚═╝║╚═╝║╚═╝║║║╚╦╣╠╗ ║║
      ╚╝ ╚═══╩═══╩═══╩╝╚═╩══╝ ╚╝'''

    # %%Logo Operate

    # Do not run.
    # Debugging~
    # def __debuging__setlogo__(logof):
    #     global logoe
    #     logoe=logof
    # if logoe=='':
    #     pass
    # else:
    #     logo==logoe
    # def _nologo():
    #     global logog
    #     logog=''''''
    # if not logog=='':
    #     pass
    # if logog=='':
    #     logo==logog
    print(logo)
    __runfst__()


def python_call_powershell(file,*o):
    try:
        args=[r"powershell.exe","-ExecutionPolicy","Unrestricted", file,o]  #args参数里的ip是对应调用powershell里的动态参数args[0],类似python中的sys.argv[1]
        p=subprocess.Popen(args, stdout=subprocess.PIPE)
        dt=p.stdout.read()
        return dt
    except Exception as e:
        print(e)
    return False


class clear:
    def __init__(self):
        os.system("cls")


unarchive = archive.unfile
make_archive = archive.addfile
pip_install = piptools.install
pip_uninstall = piptools.uninstall
pip_reinstall = piptools.reinstall
pwh=winshell.powershell



# -*- coding: utf-8 -*-
"""
Created on Fri Jan 13 17:28:15 2023

@author: Administrator
"""
import os


def unfile(file, filedir=''):
    if not not filedir:
        fd = '-o'+filedir
        mode = 'x'
    else:
        mode = 'e'
    # start
    os.system('7z '+mode+' '+file+' '+fd)


def hashfile(*file, methods=''):
    # Supported methods: CRC32, CRC64, SHA1, SHA256, BLAKE2sp. Default method is CRC32.
    if not not methods:
        for temp in methods:
            os.system('7z h '+'-scrc'+temp+''+file)
    else:
        os.system('7z h '+file)


def delfile(file1, df, rt=''):
    if '*' in df:
        rt = r'-r'
    os.system('7z d '+file1+' '+df+' ' + rt)


def addfile(file, files):
    os.system('7z a '+file+' '+files)



# -*- coding: utf-8 -*-
"""
Created on Fri Jan 13 18:59:17 2023

@author: Administrator
"""
import ntplib,datetime,sudo
def __r(url):
    c = ntplib.NTPClient()
    
    hosts = ['edu.ntp.org.cn', 'tw.ntp.org.cn', 'us.ntp.org.cn', 'cn.pool.ntp.org', 'jp.ntp.org.cn']
    # hosts=url
    for host in hosts:
    
        try:
    
            response = c.request(host)
    
            if response:
    
                break
    
        except Exception as e:
    
            print(e)
    
    current_time = response.tx_time
    
    _date, _time = str(datetime.datetime.fromtimestamp(current_time))[:22].split(' ')
    
    print("系统当前时间", str(datetime.datetime.now())[:22])
    
    print("北京标准时间", _date, _time)
    
    a, b, c = _time.split(':')
    
    c = float(c) + 0.5
    
    _time = "%s:%s:%s" % (a, b, c)
    
    eval(r"os.system('date %s && time %s' % (_date, _time))")
    print("同步后时间:", str(datetime.datetime.now())[:22])
    class ct(url):
        def __init__(url):
            sudo.sudopy(__r(url))


# -*- coding: utf-8 -*-
"""
Created on Fri Jan 13 18:46:11 2023

@author: Administrator
"""
import os,platform,winshell,file
def sudopy(*shell,password='',timeout=1800000):
    if platform.system()=='Windows':
        with open("temp.py",'a') as f:
            f.write(shell)
        winshell.powershell(r"sudo.ps1", r"py temp.py")
    elif platform.system()=='Linux':
        with open("temp.py",'a') as f:
            f.write(shell)
        if not password:
            os.system('sudo python temp.py')
        else:
            os.system('sudo -S '+password+' python temp.py')
    file.rmfile(r"temp.py")
    
def sudo(shell,password='',timeout=1800000):
    if platform.system()=='Windows':
        winshell.powershell(r"sudo.ps1", shell)
    elif platform.system()=='Linux':
        if not password:
            os.system('sudo python temp.py')
        else:
            os.system('sudo -S '+password+' python temp.py')


# -*- coding: utf-8 -*-
"""
Created on Sun Nov 27 10:40:59 2022

@author: Administrator
"""
import setuptools,os,time
import shutil
from setuptools import find_packages



print('捆绑安装依赖~')
print('Bundle installation dependencies~')
awsw=os.path.exists("a.op")
if awsw==True:
    pass
else:
    os.system("cd 7z && python inst.py")
    os.system('cd ..')
    time.sleep(10)
    shutil.rmtree('7z')
with open("README", "r", encoding="utf-8") as fh:
    long_description = fh.read()
 
setuptools.setup(
    name="lantoolkit", # 用自己的名替换其中的YOUR_USERNAME_
    version="0.4.1",    #包版本号，便于维护版本
    author="Lan",    #作者，可以写自己的姓名
    author_email="soft-diyuge@outlook.com",    #作者联系方式，可写自己的邮箱地址
    description="A small toolkit",#包的简述
    long_description=long_description,    #包的详细介绍，一般在README.md文件内
    long_description_content_type="text/markdown",
    url="https://gitee.com/supollad/py-toolkit",    #自己项目地址，比如github的项目地址
    packages=find_packages(),
    install_requires=['auto-py-to-exe','ntplib','rish','spyder'],
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    entry_points = {
        'console_scripts': ['cheek_ntp=lantoolkit.ntptools:ct']
    },
    python_requires='>=3.4',    #对python的最低版本要求
)